@@ -698,7 +698,7 @@ class TabletCanvas(EventDispatcher):
             :event:
             """
 
-        def on_motion(self, cursor, x, y, pressure):
+        def on_motion(self, cursor, x, y, pressure, tilt_x, tilt_y):
             """The cursor moved on the tablet surface.
 
             If `pressure` is 0, then the cursor is actually hovering above the
